pub enum ExecutionProvider {
Cuda,
Cpu,
}Expand description
The hardware backend an NliClassifier runs its inference on.
Variants
Cuda
NVIDIA CUDA. Only reachable when the cuda cargo feature is enabled.
Cpu
CPU (MLAS). The default, and the only option without the cuda feature.
Implementations